pub struct TagRef<'a> {
pub target: &'a BStr,
pub target_kind: Kind,
pub name: &'a BStr,
pub tagger: Option<&'a BStr>,
pub message: &'a BStr,
pub pgp_signature: Option<&'a BStr>,
}Expand description
Represents a git tag, commonly indicating a software release.
Fields
target: &'a BStrThe hash in hexadecimal being the object this tag points to. Use target() to obtain a byte representation.
target_kind: KindThe kind of object that target points to.
name: &'a BStrThe name of the tag, e.g. “v1.0”.
tagger: Option<&'a BStr>The raw tagger header value as encountered during parsing.
Use the tagger() method to obtain a parsed version of it.
message: &'a BStrThe message describing this release.
pgp_signature: Option<&'a BStr>A cryptographic signature over the entire content of the serialized tag object thus far.
Implementations