pub enum Default {
Nothing,
Current,
Upstream,
Simple,
Matching,
}Expand description
All possible values of push.default.
Variants
Nothing
Do not push anything unless a refspec is provided explicitly.
This is for safety.
Current
Push the current branch to update a remote branch with the same name.
Upstream
Push the current branch to the branch it would fetch from and merge with,
i.e. what is configured in branch.<name>.merge, retrievable with
the @{upstream} refspec.
Simple
Push the current branch with the same name to the remote.
This is the same as Current, but fails if
branch.<name>.merge is set to a branch that is named differently.
Matching
Push all branches to their similarly named counterpart on the remote.